#
# spec file for package fwknop
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 3
%define libname libfko%{sover}

Name:           fwknop
Version:        2.6.11
Release:        1.5
Summary:        The fwknop Client
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Security
URL:            https://www.cipherdyne.org/fwknop/
#Git-Clone:     https://github.com/mrash/fwknop.git
Source:         https://www.cipherdyne.org/fwknop/download/%{name}-%{version}.tar.bz2
Source1:        https://www.cipherdyne.org/fwknop/download/%{name}-%{version}.tar.bz2.asc#/%{name}-%{version}.tar.bz2.sig
# https://www.cipherdyne.org/signing_key
Source2:        %{name}.keyring
Source3:        %{name}d.service
BuildRequires:  gdbm-devel
BuildRequires:  gpg2
BuildRequires:  iptables
BuildRequires:  libgpgme-devel
BuildRequires:  libpcap-devel
BuildRequires:  systemd-rpm-macros

%description
fwknop stands for the "FireWall KNock OPerator", and implements an authorization
scheme called Single Packet Authorization (SPA).

%package -n %{libname}
Summary:        The Firewall Knock Operator Library
Group:          System/Libraries

%description -n %{libname}
The Firewall Knock Operator library, libfko, provides the Single Packet
Authorization implementation and API for the other fwknop components.

%package -n libfko-devel
Summary:        The Development Files for the Firewall Knock Operator Library
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires(post): %{install_info_prereq}
Requires(preun): %{install_info_prereq}

%description -n libfko-devel
The Firewall Knock Operator library, libfko, provides the Single Packet
Authorization implementation and API for the other fwknop components.

This subpackage contains libraries and header files for developing
applications that want to make use of libfko.

%package -n fwknopd
Summary:        The fwknop Server
Group:          Productivity/Networking/Security
%{?systemd_requires}

%description -n fwknopd
fwknop stands for the "FireWall KNock OPerator", and implements an authorization
scheme called Single Packet Authorization (SPA).

%prep
%setup -q

%build
%configure --disable-static
%make_build

%check
%make_build check

%install
%make_install
install -D -m 644 %{SOURCE3} %{buildroot}/%{_unitdir}/%{name}d.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}d
find %{buildroot} -type f -name "*.la" -delete -print

%pre -n fwknopd
%service_add_pre %{name}d.service

%post -n fwknopd
%service_add_post %{name}d.service

%preun -n fwknopd
%service_del_preun %{name}d.service

%postun -n fwknopd
%service_del_postun %{name}d.service

%post -n libfko-devel
%install_info --info-dir=%{_infodir} %{_infodir}/libfko.info.gz

%postun -n libfko-devel
%install_info_delete --info-dir=%{_infodir} %{_infodir}/libfko.info.gz

%ldconfig_scriptlets -n %{libname}

%files
%license COPYING
%doc AUTHORS CREDITS NEWS README
%{_bindir}/fwknop
%{_mandir}/man8/fwknop.8%{?ext_man}

%files -n fwknopd
%{_unitdir}/%{name}d.service
%{_sbindir}/rc%{name}d
%{_sysconfdir}/fwknop
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/fwknop/access.conf
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/fwknop/fwknopd.conf
%{_sbindir}/fwknopd
%{_mandir}/man8/fwknopd.8%{?ext_man}

%files -n %{libname}
%{_libdir}/libfko.so.%{sover}*

%files -n libfko-devel
%{_includedir}/fko.h
%{_libdir}/libfko.so
%{_infodir}/libfko.info%{?ext_info}

%changelog
* Mon Mar 18 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 2.6.11
  * Seed random() at least a bit before using random().
  * Fix two erroneous calls to strlcat().
  * Use execvp() instead of execvpe().
  * Use HTTP/1.1 when communicating over HTTP.
  * khorben/coverity/1355235 TOCTOU.
  * Include systemd unit files in tarballs.
  * Remove obsolete @setcontentsaftertitlepage command.
  * Fix snprintf buffer length.
  * Soften the message when the stanza is not the correct one.
  * Add missing /etc/gai.conf to AppArmor profile.
  * Add missing "Wants" directive in systemd unit file.
  * Restart fwknop-server on failure.
  * Fix compile warnings.
* Thu Sep 16 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * fwknopd.service
* Sun Jun  7 2020 Martin Hauke <mardnh@gmx.de>
- Set CFLAGS+=-fcommon
* Mon Feb 25 2019 Martin Hauke <mardnh@gmx.de>
- Initial package, version 2.6.10
  based on home:dj9pz:network:utilities/fwknop
  - Run spec-cleaner
  - Add source verification
  - Update to version 2.6.10
